@@ -4,17 +4,45 @@
 #print("module {0}".format(__name__))
 
 import sys
+import math
+import re
+
+
+# Python2to3 support
 if sys.version > '3':
     long = int
     basestring = (str, bytes)
     unicode = str
-else:
-    long = long
-    basestring = basestring
-    unicode = unicode
+    xrange = range
 
-import math
-import re
+    def ns2b(x):
+        """
+        Converts from native str type to native bytes type
+        """
+        return x.encode('ISO-8859-1')
+
+    def ns2u(x):
+        """
+        Converts from native str type to native unicode type
+        """
+        return x
+
+else:
+    #long = long
+    #basestring = basestring
+    #unicode = unicode
+
+    def ns2b(x):
+        """
+        Converts from native str type to native bytes type
+        """
+        return x
+
+    def ns2u(x):
+        """
+        Converts from native str type to native unicode type
+        """
+        return unicode(x)
 
 
 #Globals
